@@ -9,6 +9,7 @@ import concurrent.futures
 import tenacity
 import requests
 from bs4 import BeautifulSoup
+from ..exceptions import MaximumRequestsError
 
 HEADERS = {"headers": {"User-Agent": "Mozilla/5.0"}}
 # Retry 10 times, starting with 0.01 second and doubling the delay every time
@@ -18,10 +19,6 @@ _RETRY_ARGS = {
 }
 
 
-class MaximumRequestsError(Exception):
-    """Exceeds maximum get requests."""
-
-
 def yield_html(url, **kwargs):
     """Yields HTML content(s) to caller."""
     try:
